@@ -5,11 +5,11 @@ must implement, ensuring consistent API across different model types.
 """
 
 from abc import ABC, abstractmethod
-from typing import Optional, Union, Tuple
+from typing import Optional, Union, Tuple, Any
 import numpy as np
 
 from ..config import DFMConfig
-from ..core.results import DFMResult
+from ..config.results import BaseResult
 
 
 class BaseFactorModel(ABC):
@@ -23,20 +23,14 @@ class BaseFactorModel(ABC):
     ----------
     _config : Optional[DFMConfig]
         Current configuration object
-    _data : Optional[np.ndarray]
-        Current data matrix (T x N)
-    _result : Optional[DFMResult]
+    _result : Optional[BaseResult]
         Last fit result
-    _time : Optional[TimeIndex]
-        Time index for data (optional, for models that support it)
     """
     
     def __init__(self):
         """Initialize factor model instance."""
         self._config: Optional[DFMConfig] = None
-        self._data: Optional[np.ndarray] = None
-        self._result: Optional[DFMResult] = None
-        self._time: Optional[Any] = None  # TimeIndex type, avoiding circular import
+        self._result: Optional[BaseResult] = None
     
     @property
     def config(self) -> Optional[DFMConfig]:
@@ -44,28 +38,18 @@ class BaseFactorModel(ABC):
         return self._config
     
     @property
-    def data(self) -> Optional[np.ndarray]:
-        """Get current data matrix (T x N)."""
-        return self._data
-    
-    @property
-    def result(self) -> Optional[DFMResult]:
+    def result(self) -> Optional[BaseResult]:
         """Get last fit result."""
         return self._result
     
-    @property
-    def time(self) -> Optional[Any]:
-        """Get time index (if available)."""
-        return self._time
-    
     @abstractmethod
-    def fit(self, X: np.ndarray, config: DFMConfig, **kwargs) -> DFMResult:
+    def fit(self, data_module: Any, config: DFMConfig, **kwargs) -> BaseResult:
         """Fit the factor model.
         
         Parameters
         ----------
-        X : np.ndarray
-            Data matrix (T x N), where T is time periods and N is number of series.
+        data_module : DFMDataModule
+            DataModule containing preprocessed data. Must have setup() called.
         config : DFMConfig
             Configuration object specifying model structure and parameters.
         **kwargs
@@ -73,26 +57,38 @@ class BaseFactorModel(ABC):
             
         Returns
         -------
-        DFMResult
+        BaseResult
             Estimation results including parameters, factors, and diagnostics.
+            Returns DFMResult for linear DFM, DDFMResult for DDFM.
         """
         pass
     
     @abstractmethod
-    def predict(self, horizon: Optional[int] = None, **kwargs) -> Union[np.ndarray, Tuple[np.ndarray, np.ndarray]]:
+    def predict(
+        self,
+        horizon: Optional[int] = None,
+        *,
+        return_series: bool = True,
+        return_factors: bool = True
+    ) -> Union[np.ndarray, Tuple[np.ndarray, np.ndarray]]:
         """Forecast future values.
         
         Parameters
         ----------
         horizon : int, optional
             Number of periods ahead to forecast. If None, uses default based on clock frequency.
-        **kwargs
-            Additional forecast parameters.
+        return_series : bool, default True
+            Whether to return forecasted series.
+        return_factors : bool, default True
+            Whether to return forecasted factors.
             
         Returns
         -------
         np.ndarray or Tuple[np.ndarray, np.ndarray]
             Forecasted series (and optionally factors). Shape depends on model.
+            - If both return_series and return_factors are True: (X_forecast, Z_forecast)
+            - If only return_series is True: X_forecast
+            - If only return_factors is True: Z_forecast
         """
         pass
 
